j and k (r.jk) and between h and m (r.hm) differ in magnitude. Because the significance depends on the pairwise intercorrelations between all of the variables involved (j,
k, h, and m),
these intercorrelations have to be provided as additional parameters. The function expects correlation coefficients as input.
cocor.dep.groups.nonoverlap(r.jk, r.hm, r.jh, r.jm, r.kh, r.km, n, alternative = "two.sided", test = "all", alpha = 0.05, conf.level = 0.95, null.value = 0, data.name = NULL, var.labels = NULL, return.htest = FALSE)two.sided"; default) or one-sided ("greater" or "less",
depending on the direction). Optionally,
the initial letter of the character strings ("t", "g", and "l)" can be used.pearson1898,
dunn1969, steiger1980, raghunathan1996, silver2004,
or zou2007). Use all to apply all tests (default). For further information see the tests section below.zou2007 is used). The default value is $.95$.zou2007 that uses a confidence interval is available.FALSE.zou2007 is used).zou2007 is used).zou2007 is used).zou2007 is used).Pearson, K., & Filon, L. N. G. (1898). Mathematical contributions to theory of evolution: IV. On the probable errors of frequency constants and on the influence of random selection and correlation. Philosophical Transactions of the Royal Society of London, Series A, 191, 229-311. doi:10.1098/rsta.1898.0007
Raghunathan, T. E., Rosenthal, R., & Rubin, D. B., (1996). Comparing correlated but nonoverlapping correlations. Psychological Methods, 1, 178-183. doi:10.1037//1082-989X.1.2.178
Silver, N. C., & Dunlap, W. P. (1987). Averaging correlation coefficients: Should Fisher's Z transformation be used? Journal of Applied Psychology, 72, 146-148. doi:10.1037//0021-9010.72.1.146
Silver, N. C., Hittner, J. B., & May, K. (2004). Testing dependent correlations with nonoverlapping variables: A Monte Carlo simulation. Journal of Experimental Education, 73, 53-69. doi:10.3200/JEXE.71.1.53-70
Steiger, J. H. (1980). Tests for comparing elements of a correlation matrix. Psychological Bulletin, 87, 245-251. doi:10.1037//0033-2909.87.2.245
Zou, G. Y. (2007). Toward using confidence intervals to compare correlations. Psychological Methods, 12, 399-413. doi:10.1037/1082-989X.12.4.399
# Compare the difference between the correlations (age, intelligence) and
# body mass (index, shoe size) measured in the same group (all values are fictional):
r.jk <- .2 # Correlation (age, intelligence)
r.hm <- .7 # Correlation (body mass index, shoe size)
r.jh <- .4 # Correlation (age, body mass index)
r.jm <- .5 # Correlation (age, shoe size)
r.kh <- .1 # Correlation (intelligence, body mass index)
r.km <- .3 # Correlation (intelligence, shoe size)
n <- 232 # Size of the group
cocor.dep.groups.nonoverlap(r.jk, r.hm, r.jh, r.jm, r.kh, r.km, n,
var.labels=c("age", "intelligence", "body mass index", "shoe size"))
Run the code above in your browser using DataLab